@@ -3,6 +3,7 @@
 import click
 from pypelinez.feature import feature
 from pypelinez.release import release
+from pypelinez.publish import publish
 from pypelinez.apple import apple
 from pypelinez.python import python
 
@@ -15,6 +16,7 @@ def main():
 
 main.add_command(feature)
 main.add_command(release)
+main.add_command(publish)
 main.add_command(apple)
 main.add_command(python)
 
